%bcond_with pcre_regex

Name: file
Version: 5.32
Release: 7
License: BSD-2-Clause
Summary: A utility for determining file types
Url: http://www.darwinsys.com/file/

Requires: file-magic = %{version}-%{release}

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool

BuildRequires: zlib-devel

%if %{with pcre_regex}
BuildRequires: pcre-devel
%endif

Source0: ftp://ftp.astron.com/pub/file/file-%{version}.tar.gz

Patch0: file-aix-hang.patch


%description
The file command is "a file type guesser", that is, a command-line tool that
tells you in words what kind of data a file contains. Unlike most GUI systems,
command-line UNIX systems - with this program leading the charge - don't rely on
filename extentions to tell you the type of a file, but look at the file's
actual contents. This is, of course, more reliable, but requires a bit of I/O.

%package -n libmagic1
Summary: A library for determining file types
Requires: file-magic = %{version}-%{release}

%description -n libmagic1
The file command is "a file type guesser", that is, a command-line tool that
tells you in words what kind of data a file contains. Unlike most GUI systems,
command-line UNIX systems - with this program leading the charge - don't rely on
filename extentions to tell you the type of a file, but look at the file's
actual contents. This is, of course, more reliable, but requires a bit of I/O.

%package magic
Summary: File type guesser database

%description magic
The file command is "a file type guesser", that is, a command-line tool that
tells you in words what kind of data a file contains. Unlike most GUI systems,
command-line UNIX systems - with this program leading the charge - don't rely on
filename extentions to tell you the type of a file, but look at the file's
actual contents. This is, of course, more reliable, but requires a bit of I/O.

%package devel
Summary: Development tools for file type determination library
Requires: libmagic1 = %{version}-%{release}

%description devel
The file command is "a file type guesser", that is, a command-line tool that
tells you in words what kind of data a file contains. Unlike most GUI systems,
command-line UNIX systems - with this program leading the charge - don't rely on
filename extentions to tell you the type of a file, but look at the file's
actual contents. This is, of course, more reliable, but requires a bit of I/O.

%prep
%setup -q

%if %{without pcre_regex}
%patch0 -p1
%else
# So file can use the PCRE regex functions
ln -s %{_includedir}/pcreposix.h src/regex.h
%endif

%build

autoreconf -fi

%configure \
  LDFLAGS="-Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
%if %{with pcre_regex}
  CPPFLAGS='-DPCREPOSIX_COMPAT' \
  LIBS='-lpcreposix' \
%endif
  --with-aix-soname=svr4 \
  --enable-shared \
  --disable-static \
  --disable-nls

# https://stackoverflow.com/a/12080251/3245633
# This can cause an infinite loop as strndup overwrites random memory with 0s
# which may overwrite the ml->next pointer, causing the loop condition to never
# be hit in file_softmagic:
# for (ml = ms->mlist[0]->next; ml != ms->mlist[0]; ml = ml->next)
# ms->mlist[0] = 0x20003070
# ml = 0x20003130, ml->next = 0x20003070
# ...
# strndup("", 51k)
# ml = 0x20003130, ml->next = 0x0
# ml = ml->next
# ml == ms->mlist[0] ? FALSE
perl -p -i -e 's|#define HAVE_STRNDUP 1|/* #undef HAVE_STRNDUP */|' config.h

%make_build

%install

%make_install

%files
%defattr(-, qsys, *none)

%{_bindir}/file
%{_mandir}/man1/file.1*


%files -n libmagic1
%defattr(-, qsys, *none)

%{_libdir}/libmagic.so.1*


%files magic
%defattr(-, qsys, *none)

%{_datadir}/misc/magic.mgc
%{_mandir}/man4/magic.4*


%files devel
%defattr(-, qsys, *none)

%{_libdir}/libmagic.so
%{_mandir}/man3/libmagic.3*
%{_includedir}/magic.h

%changelog
* Thu Nov 4 2021 Jason Hansen <stymie@us.ibm.com> - 5.32
- Intra-package Requires need version and release

* Wed Nov 18 2020 Abdirahim Musse <abdirahim.musse@ibm.com> - 5.32
- Use brp-rm-libtool-files

* Wed May 27 2020 Kevin Adler <kadler@us.ibm.com> - 5.32
- Use generic paths for man and info pages to allow for compression

* Wed Nov 20 2019 Kevin Adler <kadler@us.ibm.com> - 5.32
- Don't use PCRE by default. Turns out it's slower, but leave it as a conditional
- Use SPDX license identifier

* Fri Jan 04 2019 - Kevin Adler <kadler@us.ibm.com>
- Try using PCRE for POSIX regex functions (libpcreposix) to avoid AIX regex bugs

* Thu Jul 19 2018 - Kevin Adler <kadler@us.ibm.com>
- Disable problematic regex causing infinite loops in rpmbuild for Node.js

* Fri Mar 23 2018 - Jesse R. Gorzinski <jgorzins@us.ibm.com>
- Bump to 5.32

* Sat Mar 03 2018 - Kevin Adler <kadler@us.ibm.com>
- use perl -pie instead of GNU sed -i
- Remove gcc wrappers from specs
- Add build requirements
- various other fixes

* Wed Nov 22 2017 - Kevin Adler <kadler@us.ibm.com>
- Update BuildRequires

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Add defattr to file package

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Use auto dependency resolution instead of requiring pase-libs

* Tue Nov 07 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix license

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- Add GCC wrappers to fix 64-bit builds
